@@ -10,7 +10,7 @@ import matplotlib as mpl
 import re
 from scipy import signal
 import scipy as sp
-import src.DRS_code.Functions.IQCalibration as IQCal
+import DRS_code.Functions.IQCalibration as IQCal
 import os
 import pickle
 
