@@ -2,7 +2,7 @@ import h5py
 import sys
 import numpy as np
 import pandas as pd
-from src.DRS_code.Functions import GUI as G
+from DRS_code.Functions import GUI as G
 import argparse
 
 def parse():
